@@ -36,6 +36,8 @@ class UseCaseOutcome:
         submitting it to Swimlane
         """
         et: DateTime = pendulum.now()
+
+        # we need to change the fields_changed datetimes to the current date/time as it is only saved now.
         p_load: Dict[str, Any] = {
             "status": status,
             "application_name": "test_application",
@@ -73,6 +75,11 @@ class UseCaseOutcome:
     def metric(self, metric_name: str, metric_value: Any):
         self.metrics.append({"metric_name": metric_name, "metric_value": metric_value})
 
+    def record_saved(self):
+        # when the records saved, can we update all the entries in field_changed with the current date_time?
+        for field_changed in self.fields_changed:
+            field_changed["timestamp"] = pendulum.now().to_iso8601_string()
+
     def field_changed(
         self, field_name: str, old_field_value: str, new_field_value: str
     ):
@@ -84,6 +91,7 @@ class UseCaseOutcome:
             }
         )
 
+
     @staticmethod
     def _normalise_keys(d: dict) -> dict:
         # returns the dict with _ replaced with spaces and each word capitalised.
